@@ -4,8 +4,8 @@
 ## Author:      Mattia Barbon
 ## Modified by:
 ## Created:     04/12/2001
-## RCS-ID:      $Id: Grid.pm 2057 2007-06-18 23:03:00Z mbarbon $
-## Copyright:   (c) 2001-2002, 2004-2006 Mattia Barbon
+## RCS-ID:      $Id: Grid.pm 3316 2012-07-14 02:05:19Z mdootson $
+## Copyright:   (c) 2001-2002, 2004-2007 Mattia Barbon
 ## Licence:     This program is free software; you can redistribute it and/or
 ##              modify it under the same terms as Perl itself
 #############################################################################
@@ -22,6 +22,8 @@ $VERSION = '0.01';
 Wx::load_dll( 'adv' );
 Wx::wx_boot( 'Wx::Grid', $VERSION );
 
+SetEvents();
+
 #
 # properly setup inheritance tree
 #
@@ -59,6 +61,16 @@ package Wx::PlGridCellEditor; @ISA = qw(Wx::GridCellEditor);
 package Wx::GridTableBase;
 package Wx::PlGridTable; @ISA = qw(Wx::GridTableBase);
 
+package Wx::Event;
+# allow 2.8 / 2.9 event name changes compatibility
+if(defined(&Wx::Event::EVT_GRID_CELL_CHANGED)) {
+  *Wx::Event::EVT_GRID_CELL_CHANGE = \&Wx::Event::EVT_GRID_CELL_CHANGED;
+  *Wx::Event::EVT_GRID_CMD_CELL_CHANGE = \&Wx::Event::EVT_GRID_CMD_CELL_CHANGED;
+} else {
+  *Wx::Event::EVT_GRID_CELL_CHANGED = \&Wx::Event::EVT_GRID_CELL_CHANGE;
+  *Wx::Event::EVT_GRID_CMD_CELL_CHANGED = \&Wx::Event::EVT_GRID_CMD_CELL_CHANGE;
+}
+
 package Wx::Grid;
 
 use strict;
