@@ -3,7 +3,7 @@
 // Purpose:     constants for Wx::STC
 // Author:      Marcus Friedlaender and Mattia Barbon
 // Created:     23/05/2002
-// RCS-ID:      $Id: st_constants.cpp 2947 2010-08-01 14:10:04Z mbarbon $
+// RCS-ID:      $Id: st_constants.cpp 3404 2012-10-01 15:44:18Z mdootson $
 // Copyright:   (c) 2002-2006, 2008, 2010 Marcus Friedlaender and Mattia Barbon
 // Licence:     This program is free software; you can redistribute it and/or
 //              modify it under the same terms as Perl itself
@@ -65,6 +65,43 @@ double stc_constant( const char* name, int arg )
 #endif
         break;
     case 'A':
+#if WXPERL_W_VERSION_GE( 2, 9, 5 )
+        r( wxSTC_A68K_DEFAULT );
+        r( wxSTC_A68K_COMMENT );
+        r( wxSTC_A68K_NUMBER_DEC );
+        r( wxSTC_A68K_NUMBER_BIN );
+        r( wxSTC_A68K_NUMBER_HEX );
+        r( wxSTC_A68K_STRING1 );
+        r( wxSTC_A68K_OPERATOR );
+        r( wxSTC_A68K_CPUINSTRUCTION );
+        r( wxSTC_A68K_EXTINSTRUCTION );
+        r( wxSTC_A68K_REGISTER );
+        r( wxSTC_A68K_DIRECTIVE );
+        r( wxSTC_A68K_MACRO_ARG );
+        r( wxSTC_A68K_LABEL );
+        r( wxSTC_A68K_STRING2 );
+        r( wxSTC_A68K_IDENTIFIER );
+        r( wxSTC_A68K_MACRO_DECLARATION );
+        r( wxSTC_A68K_COMMENT_WORD );
+        r( wxSTC_A68K_COMMENT_SPECIAL );
+        r( wxSTC_A68K_COMMENT_DOXYGEN );
+        r( wxSTC_ASM_COMMENTDIRECTIVE );
+        r( wxSTC_AVS_DEFAULT );
+        r( wxSTC_AVS_COMMENTBLOCK );
+        r( wxSTC_AVS_COMMENTBLOCKN );
+        r( wxSTC_AVS_COMMENTLINE );
+        r( wxSTC_AVS_NUMBER );
+        r( wxSTC_AVS_OPERATOR );
+        r( wxSTC_AVS_IDENTIFIER );
+        r( wxSTC_AVS_STRING );
+        r( wxSTC_AVS_TRIPLESTRING );
+        r( wxSTC_AVS_KEYWORD );
+        r( wxSTC_AVS_FILTER );
+        r( wxSTC_AVS_PLUGIN );
+        r( wxSTC_AVS_FUNCTION );
+        r( wxSTC_AVS_CLIPPROP );
+        r( wxSTC_AVS_USERDFN );
+#endif        
         r( wxSTC_AVE_DEFAULT );
         r( wxSTC_AVE_COMMENT );
         r( wxSTC_AVE_NUMBER );
@@ -191,6 +228,11 @@ double stc_constant( const char* name, int arg )
         r( wxSTC_AVE_WORD4 );
         r( wxSTC_AVE_WORD5 );
         r( wxSTC_AVE_WORD6 );
+#if WXPERL_W_VERSION_GE( 2, 9, 4 )
+        r( wxSTC_ANNOTATION_HIDDEN );
+        r( wxSTC_ANNOTATION_STANDARD );
+        r( wxSTC_ANNOTATION_BOXED );
+#endif
         break;
     case 'B':
         r( wxSTC_B_DEFAULT );
@@ -235,6 +277,47 @@ double stc_constant( const char* name, int arg )
 #endif
         break;
     case 'C':
+#if WXPERL_W_VERSION_GE( 2, 9, 5 )
+        r( wxSTC_C_STRINGRAW );
+        r( wxSTC_C_TRIPLEVERBATIM );
+        r( wxSTC_C_HASHQUOTEDSTRING );
+        r( wxSTC_C_PREPROCESSORCOMMENT );
+        r( wxSTC_CASEINSENSITIVEBEHAVIOUR_RESPECTCASE );
+        r( wxSTC_CASEINSENSITIVEBEHAVIOUR_IGNORECASE );
+        r( wxSTC_CARETSTICKY_OFF );
+        r( wxSTC_CARETSTICKY_ON );
+        r( wxSTC_CARETSTICKY_WHITESPACE );
+        r( wxSTC_COFFEESCRIPT_DEFAULT );
+        r( wxSTC_COFFEESCRIPT_COMMENT );
+        r( wxSTC_COFFEESCRIPT_COMMENTLINE );
+        r( wxSTC_COFFEESCRIPT_COMMENTDOC );
+        r( wxSTC_COFFEESCRIPT_NUMBER );
+        r( wxSTC_COFFEESCRIPT_WORD );
+        r( wxSTC_COFFEESCRIPT_STRING );
+        r( wxSTC_COFFEESCRIPT_CHARACTER );
+        r( wxSTC_COFFEESCRIPT_UUID );
+        r( wxSTC_COFFEESCRIPT_PREPROCESSOR );
+        r( wxSTC_COFFEESCRIPT_OPERATOR );
+        r( wxSTC_COFFEESCRIPT_IDENTIFIER );
+        r( wxSTC_COFFEESCRIPT_STRINGEOL );
+        r( wxSTC_COFFEESCRIPT_VERBATIM );
+        r( wxSTC_COFFEESCRIPT_REGEX );
+        r( wxSTC_COFFEESCRIPT_COMMENTLINEDOC );
+        r( wxSTC_COFFEESCRIPT_WORD2 );
+        r( wxSTC_COFFEESCRIPT_COMMENTDOCKEYWORD );
+        r( wxSTC_COFFEESCRIPT_COMMENTDOCKEYWORDERROR );
+        r( wxSTC_COFFEESCRIPT_GLOBALCLASS );
+        r( wxSTC_COFFEESCRIPT_STRINGRAW );
+        r( wxSTC_COFFEESCRIPT_TRIPLEVERBATIM );
+        r( wxSTC_COFFEESCRIPT_HASHQUOTEDSTRING );
+        r( wxSTC_COFFEESCRIPT_COMMENTBLOCK );
+        r( wxSTC_COFFEESCRIPT_VERBOSE_REGEX );
+        r( wxSTC_COFFEESCRIPT_VERBOSE_REGEX_COMMENT );
+        r( wxSTC_CSS_MEDIA );
+        r( wxSTC_CSS_VARIABLE );
+        r( wxSTC_CURSORARROW );
+        r( wxSTC_CURSORREVERSEARROW );
+#endif        
         r( wxSTC_CHARSET_ANSI );
         r( wxSTC_CHARSET_DEFAULT );
         r( wxSTC_CHARSET_BALTIC );
@@ -396,6 +479,13 @@ double stc_constant( const char* name, int arg )
 #if WXPERL_W_VERSION_GE( 2, 6, 0 )
         r( wxSTC_CSS_IDENTIFIER2 );
 #endif
+#if WXPERL_W_VERSION_GE( 2, 9, 4 )
+        r( wxSTC_CSS_IDENTIFIER3 );
+        r( wxSTC_CSS_PSEUDOELEMENT );
+        r( wxSTC_CSS_EXTENDED_IDENTIFIER );
+        r( wxSTC_CSS_EXTENDED_PSEUDOCLASS );
+        r( wxSTC_CSS_EXTENDED_PSEUDOELEMENT );
+#endif
 #if WXPERL_W_VERSION_GE( 2, 7, 2 )
         r( wxSTC_CAML_CHAR );
         r( wxSTC_CAML_COMMENT );
@@ -412,6 +502,9 @@ double stc_constant( const char* name, int arg )
         r( wxSTC_CAML_OPERATOR );
         r( wxSTC_CAML_STRING );
         r( wxSTC_CAML_TAGNAME );
+#endif
+#if WXPERL_W_VERSION_GE( 2, 9, 4 )
+        r( wxSTC_CAML_WHITE );
 #endif
         r( wxSTC_CLW_ATTRIBUTE );
         r( wxSTC_CLW_BUILTIN_PROCEDURES_FUNCTION );
@@ -476,7 +569,9 @@ double stc_constant( const char* name, int arg )
         r( wxSTC_CMD_WORDLEFTENDEXTEND );
         r( wxSTC_CMD_WORDRIGHTEND );
         r( wxSTC_CMD_WORDRIGHTENDEXTEND );
+#if WXPERL_W_VERSION_LT( 2, 9, 5 )
         r( wxSTC_CP_DBCS );
+#endif        
         r( wxSTC_CP_UTF8 );
 #if WXPERL_W_VERSION_GE( 2, 7, 2 )
         r( wxSTC_CSOUND_ARATE_VAR );
@@ -505,6 +600,9 @@ double stc_constant( const char* name, int arg )
         r( wxSTC_DIFF_POSITION );
         r( wxSTC_DIFF_DELETED );
         r( wxSTC_DIFF_ADDED );
+#if WXPERL_W_VERSION_GE( 2, 9, 4 )        
+        r( wxSTC_DIFF_CHANGED );
+#endif           
 #if WXPERL_W_VERSION_GE( 2, 9, 0 )
         r( wxSTC_D_CHARACTER );
         r( wxSTC_D_COMMENT );
@@ -524,9 +622,45 @@ double stc_constant( const char* name, int arg )
         r( wxSTC_D_WORD );
         r( wxSTC_D_WORD2 );
         r( wxSTC_D_WORD3 );
+#endif
+#if WXPERL_W_VERSION_GE( 2, 9, 4 )
+        r( wxSTC_D_STRINGR );
+        r( wxSTC_D_WORD5 );
+        r( wxSTC_D_WORD6 );
+        r( wxSTC_D_WORD7 );
 #endif
         break;
     case 'E':
+#if WXPERL_W_VERSION_GE( 2, 9, 5 )
+        r( wxSTC_ECL_DEFAULT );
+        r( wxSTC_ECL_COMMENT );
+        r( wxSTC_ECL_COMMENTLINE );
+        r( wxSTC_ECL_NUMBER );
+        r( wxSTC_ECL_STRING );
+        r( wxSTC_ECL_WORD0 );
+        r( wxSTC_ECL_OPERATOR );
+        r( wxSTC_ECL_CHARACTER );
+        r( wxSTC_ECL_UUID );
+        r( wxSTC_ECL_PREPROCESSOR );
+        r( wxSTC_ECL_UNKNOWN );
+        r( wxSTC_ECL_IDENTIFIER );
+        r( wxSTC_ECL_STRINGEOL );
+        r( wxSTC_ECL_VERBATIM );
+        r( wxSTC_ECL_REGEX );
+        r( wxSTC_ECL_COMMENTLINEDOC );
+        r( wxSTC_ECL_WORD1 );
+        r( wxSTC_ECL_COMMENTDOCKEYWORD );
+        r( wxSTC_ECL_COMMENTDOCKEYWORDERROR );
+        r( wxSTC_ECL_WORD2 );
+        r( wxSTC_ECL_WORD3 );
+        r( wxSTC_ECL_WORD4 );
+        r( wxSTC_ECL_WORD5 );
+        r( wxSTC_ECL_COMMENTDOC );
+        r( wxSTC_ECL_ADDED );
+        r( wxSTC_ECL_DELETED );
+        r( wxSTC_ECL_CHANGED );
+        r( wxSTC_ECL_MOVED );
+#endif        
         r( wxSTC_EOL_CR );
         r( wxSTC_EOL_LF );
         r( wxSTC_EOL_CRLF );
@@ -573,6 +707,20 @@ double stc_constant( const char* name, int arg )
         r( wxSTC_ERLANG_STRING );
         r( wxSTC_ERLANG_UNKNOWN );
         r( wxSTC_ERLANG_VARIABLE );
+#if WXPERL_W_VERSION_GE( 2, 9, 4 )
+        r( wxSTC_ERLANG_PREPROC );
+        r( wxSTC_ERLANG_COMMENT_FUNCTION );
+        r( wxSTC_ERLANG_COMMENT_MODULE );
+        r( wxSTC_ERLANG_COMMENT_DOC );
+        r( wxSTC_ERLANG_COMMENT_DOC );
+        r( wxSTC_ERLANG_ATOM_QUOTED );
+        r( wxSTC_ERLANG_MACRO_QUOTED );
+        r( wxSTC_ERLANG_RECORD_QUOTED );
+        r( wxSTC_ERLANG_NODE_NAME_QUOTED );
+        r( wxSTC_ERLANG_BIFS );
+        r( wxSTC_ERLANG_MODULES );
+        r( wxSTC_ERLANG_MODULES_ATT );
+#endif
         r( wxSTC_ERR_ABSF );
         r( wxSTC_ERR_ELF );
         r( wxSTC_ERR_IFC );
@@ -597,8 +745,18 @@ double stc_constant( const char* name, int arg )
         r( wxSTC_ESCRIPT_WORD );
         r( wxSTC_ESCRIPT_WORD2 );
         r( wxSTC_ESCRIPT_WORD3 );
+#if WXPERL_W_VERSION_GE( 2, 9, 4 )
+        r( wxSTC_EFF_QUALITY_MASK ); 
+        r( wxSTC_EFF_QUALITY_DEFAULT );
+        r( wxSTC_EFF_QUALITY_NON_ANTIALIASED );
+        r( wxSTC_EFF_QUALITY_ANTIALIASED );
+        r( wxSTC_EFF_QUALITY_LCD_OPTIMIZED );
+#endif
         break;
     case 'F':
+#if WXPERL_W_VERSION_GE( 2, 9, 5 )
+        r( wxSTC_FONT_SIZE_MULTIPLIER );
+#endif        
         r( wxSTC_FIND_WHOLEWORD );
         r( wxSTC_FIND_MATCHCASE );
         r( wxSTC_FIND_WORDSTART );
@@ -652,8 +810,27 @@ double stc_constant( const char* name, int arg )
         r( wxSTC_FOLDLEVELUNINDENT );
 #endif
 #if WXPERL_W_VERSION_GE( 2, 7, 2 )
+#if WXPERL_W_VERSION_LT( 2, 9, 5 )
         r( wxSTC_FS_ASM );
         r( wxSTC_FS_BINNUMBER );
+        r( wxSTC_FS_ERROR );
+        r( wxSTC_FS_HEXNUMBER );
+        r( wxSTC_FS_LABEL );
+#else
+        r( wxSTC_FS_WORDOPERATOR );
+        r( wxSTC_FS_DISABLEDCODE );
+        r( wxSTC_FS_DEFAULT_C );
+        r( wxSTC_FS_COMMENTDOC_C );
+        r( wxSTC_FS_COMMENTLINEDOC_C );
+        r( wxSTC_FS_KEYWORD_C );
+        r( wxSTC_FS_KEYWORD2_C );
+        r( wxSTC_FS_NUMBER_C );
+        r( wxSTC_FS_STRING_C );
+        r( wxSTC_FS_PREPROCESSOR_C );
+        r( wxSTC_FS_OPERATOR_C );
+        r( wxSTC_FS_IDENTIFIER_C );
+        r( wxSTC_FS_STRINGEOL_C );
+#endif
         r( wxSTC_FS_COMMENT );
         r( wxSTC_FS_COMMENTDOC );
         r( wxSTC_FS_COMMENTDOCKEYWORD );
@@ -663,14 +840,11 @@ double stc_constant( const char* name, int arg )
         r( wxSTC_FS_CONSTANT );
         r( wxSTC_FS_DATE );
         r( wxSTC_FS_DEFAULT );
-        r( wxSTC_FS_ERROR );
-        r( wxSTC_FS_HEXNUMBER );
         r( wxSTC_FS_IDENTIFIER );
         r( wxSTC_FS_KEYWORD );
         r( wxSTC_FS_KEYWORD2 );
         r( wxSTC_FS_KEYWORD3 );
         r( wxSTC_FS_KEYWORD4 );
-        r( wxSTC_FS_LABEL );
         r( wxSTC_FS_NUMBER );
         r( wxSTC_FS_OPERATOR );
         r( wxSTC_FS_PREPROCESSOR );
@@ -855,6 +1029,13 @@ double stc_constant( const char* name, int arg )
 #if WXPERL_W_VERSION_GE( 2, 7, 2 )
         r( wxSTC_INDIC_ROUNDBOX );
 #endif
+#if WXPERL_W_VERSION_GE( 2, 9, 5 )
+        r( wxSTC_INDIC_STRAIGHTBOX );
+        r( wxSTC_INDIC_DASH );
+        r( wxSTC_INDIC_DOTS );
+        r( wxSTC_INDIC_SQUIGGLELOW );
+        r( wxSTC_INDIC_DOTBOX );
+#endif
 #if WXPERL_W_VERSION_GE( 2, 7, 2 )
         r( wxSTC_INNO_COMMENT );
         r( wxSTC_INNO_COMMENT_PASCAL );
@@ -868,6 +1049,9 @@ double stc_constant( const char* name, int arg )
 #if WXPERL_W_VERSION_LT( 2, 9, 1 )
         r( wxSTC_INNO_PREPROC_INLINE );
 #endif
+#if WXPERL_W_VERSION_GE( 2, 9, 4 )
+        r( wxSTC_INNO_INLINE_EXPANSION );
+#endif           
         r( wxSTC_INNO_SECTION );
         r( wxSTC_INNO_STRING_DOUBLE );
         r( wxSTC_INNO_STRING_SINGLE );
@@ -917,6 +1101,26 @@ double stc_constant( const char* name, int arg )
         r( wxSTC_KIX_VAR );
         break;
     case 'L':
+#if WXPERL_W_VERSION_GE( 2, 9, 5 )
+    r( wxSTC_L_TAG2 );
+        r( wxSTC_L_MATH2 );
+        r( wxSTC_L_COMMENT2 );
+        r( wxSTC_L_VERBATIM );
+        r( wxSTC_L_SHORTCMD );
+        r( wxSTC_L_SPECIAL );
+        r( wxSTC_L_CMDOPT );
+        r( wxSTC_L_ERROR );
+        r( wxSTC_LUA_LABEL );
+        r( wxSTC_LEX_TXT2TAGS );
+        r( wxSTC_LEX_A68K );
+        r( wxSTC_LEX_MODULA );
+        r( wxSTC_LEX_COFFEESCRIPT );
+        r( wxSTC_LEX_TCMD );
+        r( wxSTC_LEX_AVS );
+        r( wxSTC_LEX_ECL );
+        r( wxSTC_LEX_OSCRIPT );
+        r( wxSTC_LEX_VISUALPROLOG );
+#endif        
         r( wxSTC_LEX_ADA );
         r( wxSTC_LEX_ASM );
 #ifdef wxSTC_LEX_ASP
@@ -1050,6 +1254,20 @@ double stc_constant( const char* name, int arg )
         r( wxSTC_LEX_VERILOG );
 #if WXPERL_W_VERSION_GE( 2, 6, 0 )
         r( wxSTC_LEX_VHDL );
+#endif
+#if WXPERL_W_VERSION_GE( 2, 9, 4 )
+        r( wxSTC_LEX_MAGIK );
+        r( wxSTC_LEX_POWERSHELL );
+        r( wxSTC_LEX_MYSQL );
+        r( wxSTC_LEX_PO );
+        r( wxSTC_LEX_TAL );
+        r( wxSTC_LEX_COBOL );
+        r( wxSTC_LEX_TACL );
+        r( wxSTC_LEX_SORCUS );
+        r( wxSTC_LEX_POWERPRO );
+        r( wxSTC_LEX_NIMROD );
+        r( wxSTC_LEX_SML );
+        r( wxSTC_LEX_MARKDOWN );
 #endif
         r( wxSTC_LASTSTEPINUNDOREDO );
         r( wxSTC_L_DEFAULT );
@@ -1112,6 +1330,33 @@ double stc_constant( const char* name, int arg )
         r( wxSTC_LUA_WORD8 );
         break;
     case 'M':
+#if WXPERL_W_VERSION_GE( 2, 9, 5 )
+        r( wxSTC_MARGINOPTION_NONE );
+        r( wxSTC_MARGINOPTION_SUBLINESELECT );
+        r( wxSTC_MARK_RGBAIMAGE );
+        r( wxSTC_MOD_LEXERSTATE );
+        r( wxSTC_MODEVENTMASKALL );
+        r( wxSTC_MODULA_DEFAULT );
+        r( wxSTC_MODULA_COMMENT );
+        r( wxSTC_MODULA_DOXYCOMM );
+        r( wxSTC_MODULA_DOXYKEY );
+        r( wxSTC_MODULA_KEYWORD );
+        r( wxSTC_MODULA_RESERVED );
+        r( wxSTC_MODULA_NUMBER );
+        r( wxSTC_MODULA_BASENUM );
+        r( wxSTC_MODULA_FLOAT );
+        r( wxSTC_MODULA_STRING );
+        r( wxSTC_MODULA_STRSPEC );
+        r( wxSTC_MODULA_CHAR );
+        r( wxSTC_MODULA_CHARSPEC );
+        r( wxSTC_MODULA_PROC );
+        r( wxSTC_MODULA_PRAGMA );
+        r( wxSTC_MODULA_PRGKEY );
+        r( wxSTC_MODULA_OPERATOR );
+        r( wxSTC_MODULA_BADSTR );
+        r( wxSTC_MULTIPASTE_ONCE );
+        r( wxSTC_MULTIPASTE_EACH );
+#endif        
         r( wxSTC_MARKER_MAX );
         r( wxSTC_MARK_CIRCLE );
         r( wxSTC_MARK_ROUNDRECT );
@@ -1141,6 +1386,77 @@ double stc_constant( const char* name, int arg )
         r( wxSTC_MARK_CHARACTER );
 #if WXPERL_W_VERSION_GE( 2, 7, 2 )
         r( wxSTC_MARK_FULLRECT );
+#endif
+#if WXPERL_W_VERSION_GE( 2, 9, 4 )
+        r( wxSTC_MARK_LEFTRECT );
+        r( wxSTC_MARK_AVAILABLE );
+        r( wxSTC_MARK_UNDERLINE );
+        r( wxSTC_MARGIN_TEXT );
+        r( wxSTC_MARGIN_RTEXT );
+        r( wxSTC_MOD_CHANGEMARGIN );
+        r( wxSTC_MOD_CHANGEANNOTATION );
+        r( wxSTC_MOD_CONTAINER );
+        r( wxSTC_MAGIK_DEFAULT );
+        r( wxSTC_MAGIK_COMMENT );
+        r( wxSTC_MAGIK_HYPER_COMMENT );
+        r( wxSTC_MAGIK_STRING );
+        r( wxSTC_MAGIK_CHARACTER );
+        r( wxSTC_MAGIK_NUMBER );
+        r( wxSTC_MAGIK_IDENTIFIER );
+        r( wxSTC_MAGIK_OPERATOR );
+        r( wxSTC_MAGIK_FLOW );
+        r( wxSTC_MAGIK_CONTAINER );
+        r( wxSTC_MAGIK_BRACKET_BLOCK );
+        r( wxSTC_MAGIK_BRACE_BLOCK );
+        r( wxSTC_MAGIK_SQBRACKET_BLOCK );
+        r( wxSTC_MAGIK_UNKNOWN_KEYWORD );
+        r( wxSTC_MAGIK_KEYWORD );
+        r( wxSTC_MAGIK_PRAGMA );
+        r( wxSTC_MAGIK_SYMBOL );
+        r( wxSTC_MYSQL_DEFAULT );
+        r( wxSTC_MYSQL_COMMENT );
+        r( wxSTC_MYSQL_COMMENTLINE );
+        r( wxSTC_MYSQL_VARIABLE );
+        r( wxSTC_MYSQL_SYSTEMVARIABLE );
+        r( wxSTC_MYSQL_KNOWNSYSTEMVARIABLE );
+        r( wxSTC_MYSQL_NUMBER );
+        r( wxSTC_MYSQL_MAJORKEYWORD );
+        r( wxSTC_MYSQL_KEYWORD );
+        r( wxSTC_MYSQL_DATABASEOBJECT );
+        r( wxSTC_MYSQL_PROCEDUREKEYWORD );
+        r( wxSTC_MYSQL_STRING );
+        r( wxSTC_MYSQL_SQSTRING );
+        r( wxSTC_MYSQL_DQSTRING );
+        r( wxSTC_MYSQL_OPERATOR );
+        r( wxSTC_MYSQL_FUNCTION );
+        r( wxSTC_MYSQL_IDENTIFIER );
+        r( wxSTC_MYSQL_QUOTEDIDENTIFIER );
+        r( wxSTC_MYSQL_USER1 );
+        r( wxSTC_MYSQL_USER2 );
+        r( wxSTC_MYSQL_USER3 );
+        r( wxSTC_MYSQL_HIDDENCOMMAND );
+        r( wxSTC_MARKDOWN_DEFAULT );
+        r( wxSTC_MARKDOWN_LINE_BEGIN );
+        r( wxSTC_MARKDOWN_STRONG1 );
+        r( wxSTC_MARKDOWN_STRONG2 );
+        r( wxSTC_MARKDOWN_EM1 );
+        r( wxSTC_MARKDOWN_EM2 );
+        r( wxSTC_MARKDOWN_HEADER1 );
+        r( wxSTC_MARKDOWN_HEADER2 );
+        r( wxSTC_MARKDOWN_HEADER3 );
+        r( wxSTC_MARKDOWN_HEADER4 );
+        r( wxSTC_MARKDOWN_HEADER5 );
+        r( wxSTC_MARKDOWN_HEADER6 );
+        r( wxSTC_MARKDOWN_PRECHAR );
+        r( wxSTC_MARKDOWN_ULIST_ITEM );
+        r( wxSTC_MARKDOWN_OLIST_ITEM );
+        r( wxSTC_MARKDOWN_BLOCKQUOTE );
+        r( wxSTC_MARKDOWN_STRIKEOUT );
+        r( wxSTC_MARKDOWN_HRULE );
+        r( wxSTC_MARKDOWN_LINK );
+        r( wxSTC_MARKDOWN_CODE );
+        r( wxSTC_MARKDOWN_CODE2 );
+        r( wxSTC_MARKDOWN_CODEBK );
 #endif
         r( wxSTC_MARK_PIXMAP );
         r( wxSTC_MARKNUM_FOLDEREND );
@@ -1268,6 +1584,27 @@ double stc_constant( const char* name, int arg )
 #endif
         break;
     case 'O':
+#if WXPERL_W_VERSION_GE( 2, 9, 5 )        
+        r( wxSTC_OSCRIPT_DEFAULT );
+        r( wxSTC_OSCRIPT_LINE_COMMENT );
+        r( wxSTC_OSCRIPT_BLOCK_COMMENT );
+        r( wxSTC_OSCRIPT_DOC_COMMENT );
+        r( wxSTC_OSCRIPT_PREPROCESSOR );
+        r( wxSTC_OSCRIPT_NUMBER );
+        r( wxSTC_OSCRIPT_SINGLEQUOTE_STRING );
+        r( wxSTC_OSCRIPT_DOUBLEQUOTE_STRING );
+        r( wxSTC_OSCRIPT_CONSTANT );
+        r( wxSTC_OSCRIPT_IDENTIFIER );
+        r( wxSTC_OSCRIPT_GLOBAL );
+        r( wxSTC_OSCRIPT_KEYWORD );
+        r( wxSTC_OSCRIPT_OPERATOR );
+        r( wxSTC_OSCRIPT_LABEL );
+        r( wxSTC_OSCRIPT_TYPE );
+        r( wxSTC_OSCRIPT_FUNCTION );
+        r( wxSTC_OSCRIPT_OBJECT );
+        r( wxSTC_OSCRIPT_PROPERTY );
+        r( wxSTC_OSCRIPT_METHOD );
+#endif        
 #if WXPERL_W_VERSION_GE( 2, 7, 2 )
         r( wxSTC_OPAL_BOOL_CONST );
         r( wxSTC_OPAL_COMMENT_BLOCK );
@@ -1344,6 +1681,21 @@ double stc_constant( const char* name, int arg )
         r( wxSTC_PL_FORMAT_IDENT );
         r( wxSTC_PL_SUB_PROTOTYPE );
 #endif
+#if WXPERL_W_VERSION_GE( 2, 9, 5 )
+        r( wxSTC_PL_STRING_VAR );
+        r( wxSTC_PL_XLAT );
+        r( wxSTC_PL_REGEX_VAR );
+        r( wxSTC_PL_REGSUBST_VAR );
+        r( wxSTC_PL_BACKTICKS_VAR );
+        r( wxSTC_PL_HERE_QQ_VAR );
+        r( wxSTC_PL_HERE_QX_VAR );
+        r( wxSTC_PL_STRING_QQ_VAR );
+        r( wxSTC_PL_STRING_QX_VAR );
+        r( wxSTC_PL_STRING_QR_VAR );
+        r( wxSTC_POWERSHELL_FUNCTION );
+        r( wxSTC_POWERSHELL_USER1 );
+        r( wxSTC_POWERSHELL_COMMENTSTREAM );
+#endif
 #if WXPERL_W_VERSION_GE( 2, 7, 2 )
         r( wxSTC_PL_POD_VERB );
         r( wxSTC_PL_VARIABLE_INDEXER );
@@ -1400,6 +1752,60 @@ double stc_constant( const char* name, int arg )
         r( wxSTC_POV_WORD6 );
         r( wxSTC_POV_WORD7 );
         r( wxSTC_POV_WORD8 );
+#if WXPERL_W_VERSION_GE( 2, 9, 4 )
+        r( wxSTC_POWERSHELL_DEFAULT );
+        r( wxSTC_POWERSHELL_COMMENT );
+        r( wxSTC_POWERSHELL_STRING );
+        r( wxSTC_POWERSHELL_CHARACTER );
+        r( wxSTC_POWERSHELL_NUMBER );
+        r( wxSTC_POWERSHELL_VARIABLE );
+        r( wxSTC_POWERSHELL_OPERATOR );
+        r( wxSTC_POWERSHELL_IDENTIFIER );
+        r( wxSTC_POWERSHELL_KEYWORD );
+        r( wxSTC_POWERSHELL_CMDLET );
+        r( wxSTC_POWERSHELL_ALIAS );
+        r( wxSTC_PO_DEFAULT );
+        r( wxSTC_PO_COMMENT );
+        r( wxSTC_PO_MSGID );
+        r( wxSTC_PO_MSGID_TEXT );
+        r( wxSTC_PO_MSGSTR );
+        r( wxSTC_PO_MSGSTR_TEXT );
+        r( wxSTC_PO_MSGCTXT );
+        r( wxSTC_PO_MSGCTXT_TEXT );
+        r( wxSTC_PO_FUZZY );
+        r( wxSTC_PAS_DEFAULT );
+        r( wxSTC_PAS_IDENTIFIER );
+        r( wxSTC_PAS_COMMENT );
+        r( wxSTC_PAS_COMMENT2 );
+        r( wxSTC_PAS_COMMENTLINE );
+        r( wxSTC_PAS_PREPROCESSOR );
+        r( wxSTC_PAS_PREPROCESSOR2 );
+        r( wxSTC_PAS_NUMBER );
+        r( wxSTC_PAS_HEXNUMBER );
+        r( wxSTC_PAS_WORD );
+        r( wxSTC_PAS_STRING );
+        r( wxSTC_PAS_STRINGEOL );
+        r( wxSTC_PAS_CHARACTER );
+        r( wxSTC_PAS_OPERATOR );
+        r( wxSTC_PAS_ASM );
+        r( wxSTC_POWERPRO_DEFAULT );
+        r( wxSTC_POWERPRO_COMMENTBLOCK );
+        r( wxSTC_POWERPRO_COMMENTLINE );
+        r( wxSTC_POWERPRO_NUMBER );
+        r( wxSTC_POWERPRO_WORD );
+        r( wxSTC_POWERPRO_WORD2 );
+        r( wxSTC_POWERPRO_WORD3 );
+        r( wxSTC_POWERPRO_WORD4 );
+        r( wxSTC_POWERPRO_DOUBLEQUOTEDSTRING );
+        r( wxSTC_POWERPRO_SINGLEQUOTEDSTRING );
+        r( wxSTC_POWERPRO_LINECONTINUE );
+        r( wxSTC_POWERPRO_OPERATOR );
+        r( wxSTC_POWERPRO_IDENTIFIER );
+        r( wxSTC_POWERPRO_STRINGEOL );
+        r( wxSTC_POWERPRO_VERBATIM );
+        r( wxSTC_POWERPRO_ALTQUOTE );
+        r( wxSTC_POWERPRO_FUNCTION );
+#endif  
         break;
     case 'R':
 #if WXPERL_W_VERSION_GE( 2, 7, 2 )
@@ -1483,6 +1889,42 @@ double stc_constant( const char* name, int arg )
 #endif
         break;
     case 'S':
+#if WXPERL_W_VERSION_GE( 2, 9, 5 )
+        r( wxSTC_SCMOD_META );
+#endif        
+#if WXPERL_W_VERSION_GE( 2, 9, 4 )
+        r( wxSTC_STATUS_OK );
+        r( wxSTC_STATUS_FAILURE );
+        r( wxSTC_STATUS_BADALLOC );
+        r( wxSTC_SCVS_NONE );
+        r( wxSTC_SCVS_RECTANGULARSELECTION );
+        r( wxSTC_SCVS_USERACCESSIBLE );
+        r( wxSTC_SORCUS_DEFAULT );
+        r( wxSTC_SORCUS_COMMAND );
+        r( wxSTC_SORCUS_PARAMETER );
+        r( wxSTC_SORCUS_COMMENTLINE );
+        r( wxSTC_SORCUS_STRING );
+        r( wxSTC_SORCUS_STRINGEOL );
+        r( wxSTC_SORCUS_IDENTIFIER );
+        r( wxSTC_SORCUS_OPERATOR );
+        r( wxSTC_SORCUS_NUMBER );
+        r( wxSTC_SORCUS_CONSTANT );
+        r( wxSTC_SML_DEFAULT );
+        r( wxSTC_SML_IDENTIFIER );
+        r( wxSTC_SML_TAGNAME );
+        r( wxSTC_SML_KEYWORD );
+        r( wxSTC_SML_KEYWORD2 );
+        r( wxSTC_SML_KEYWORD3 );
+        r( wxSTC_SML_LINENUM );
+        r( wxSTC_SML_OPERATOR );
+        r( wxSTC_SML_NUMBER );
+        r( wxSTC_SML_CHAR );
+        r( wxSTC_SML_STRING );
+        r( wxSTC_SML_COMMENT );
+        r( wxSTC_SML_COMMENT1 );
+        r( wxSTC_SML_COMMENT2 );
+        r( wxSTC_SML_COMMENT3 );
+#endif
         r( wxSTC_STYLE_DEFAULT );
         r( wxSTC_STYLE_LINENUMBER );
         r( wxSTC_STYLE_BRACELIGHT );
@@ -1499,6 +1941,9 @@ double stc_constant( const char* name, int arg )
         r( wxSTC_SCMOD_ALT );
 #if WXPERL_W_VERSION_GE( 2, 7, 2 )
         r( wxSTC_SCMOD_NORM );
+#endif
+#if WXPERL_W_VERSION_GE( 2, 9, 4 )
+        r( wxSTC_SCMOD_SUPER );
 #endif
         r( wxSTC_SCRIPTOL_DEFAULT );
         r( wxSTC_SCRIPTOL_COMMENTLINE );
@@ -1605,7 +2050,9 @@ double stc_constant( const char* name, int arg )
         r( wxSTC_SEL_RECTANGLE );
         r( wxSTC_SEL_LINES );
 #endif
-
+#if WXPERL_W_VERSION_GE( 2, 9, 4 )
+        r( wxSTC_SEL_THIN );
+#endif
         r( wxEVT_STC_CHANGE );
         r( wxEVT_STC_STYLENEEDED );
         r( wxEVT_STC_CHARADDED );
@@ -1634,8 +2081,56 @@ double stc_constant( const char* name, int arg )
         r( wxEVT_STC_HOTSPOT_CLICK );
         r( wxEVT_STC_HOTSPOT_DCLICK );
         r( wxEVT_STC_CALLTIP_CLICK );
+#if WXPERL_W_VERSION_GE( 2, 9, 4 )
+        r( wxEVT_STC_AUTOCOMP_CANCELLED );
+        r( wxEVT_STC_AUTOCOMP_CHAR_DELETED );
+#endif
         break;
     case 'T':
+#if WXPERL_W_VERSION_GE( 2, 9, 5 )
+        r( wxSTC_TCMD_DEFAULT );
+        r( wxSTC_TCMD_COMMENT );
+        r( wxSTC_TCMD_WORD );
+        r( wxSTC_TCMD_LABEL );
+        r( wxSTC_TCMD_HIDE );
+        r( wxSTC_TCMD_COMMAND );
+        r( wxSTC_TCMD_IDENTIFIER );
+        r( wxSTC_TCMD_OPERATOR );
+        r( wxSTC_TCMD_ENVIRONMENT );
+        r( wxSTC_TCMD_EXPANSION );
+        r( wxSTC_TCMD_CLABEL );
+        r( wxSTC_TECHNOLOGY_DEFAULT );
+        r( wxSTC_TECHNOLOGY_DIRECTWRITE );
+        r( wxSTC_TXT2TAGS_DEFAULT );
+        r( wxSTC_TXT2TAGS_LINE_BEGIN );
+        r( wxSTC_TXT2TAGS_STRONG1 );
+        r( wxSTC_TXT2TAGS_STRONG2 );
+        r( wxSTC_TXT2TAGS_EM1 );
+        r( wxSTC_TXT2TAGS_EM2 );
+        r( wxSTC_TXT2TAGS_HEADER1 );
+        r( wxSTC_TXT2TAGS_HEADER2 );
+        r( wxSTC_TXT2TAGS_HEADER3 );
+        r( wxSTC_TXT2TAGS_HEADER4 );
+        r( wxSTC_TXT2TAGS_HEADER5 );
+        r( wxSTC_TXT2TAGS_HEADER6 );
+        r( wxSTC_TXT2TAGS_PRECHAR );
+        r( wxSTC_TXT2TAGS_ULIST_ITEM );
+        r( wxSTC_TXT2TAGS_OLIST_ITEM );
+        r( wxSTC_TXT2TAGS_BLOCKQUOTE );
+        r( wxSTC_TXT2TAGS_STRIKEOUT );
+        r( wxSTC_TXT2TAGS_HRULE );
+        r( wxSTC_TXT2TAGS_LINK );
+        r( wxSTC_TXT2TAGS_CODE );
+        r( wxSTC_TXT2TAGS_CODE2 );
+        r( wxSTC_TXT2TAGS_CODEBK );
+        r( wxSTC_TXT2TAGS_COMMENT );
+        r( wxSTC_TXT2TAGS_OPTION );
+        r( wxSTC_TXT2TAGS_PREPROC );
+        r( wxSTC_TXT2TAGS_POSTPROC );
+        r( wxSTC_TYPE_BOOLEAN );
+        r( wxSTC_TYPE_INTEGER );
+        r( wxSTC_TYPE_STRING );
+#endif        
         r( wxSTC_TIME_FOREVER );
 #if WXPERL_W_VERSION_GE( 2, 5, 2 )
         r( wxSTC_TEX_DEFAULT );
@@ -1691,9 +2186,45 @@ double stc_constant( const char* name, int arg )
         r( wxSTC_TCL_WORD7 );
         r( wxSTC_TCL_WORD8 );
         r( wxSTC_TCL_WORD_IN_QUOTE );
+#endif
+        break;
+    case 'U':
+#if WXPERL_W_VERSION_GE( 2, 9, 4 )
+        r( wxSTC_UNDO_MAY_COALESCE );
+#endif
+#if WXPERL_W_VERSION_GE( 2, 9, 5 )
+        r( wxSTC_UPDATE_CONTENT );
+        r( wxSTC_UPDATE_SELECTION );
+        r( wxSTC_UPDATE_V_SCROLL );
+        r( wxSTC_UPDATE_H_SCROLL );
 #endif
         break;
     case 'V':
+#if WXPERL_W_VERSION_GE( 2, 9, 5 )
+        r( wxSTC_VISUALPROLOG_DEFAULT );
+        r( wxSTC_VISUALPROLOG_KEY_MAJOR );
+        r( wxSTC_VISUALPROLOG_KEY_MINOR );
+        r( wxSTC_VISUALPROLOG_KEY_DIRECTIVE );
+        r( wxSTC_VISUALPROLOG_COMMENT_BLOCK );
+        r( wxSTC_VISUALPROLOG_COMMENT_LINE );
+        r( wxSTC_VISUALPROLOG_COMMENT_KEY );
+        r( wxSTC_VISUALPROLOG_COMMENT_KEY_ERROR );
+        r( wxSTC_VISUALPROLOG_IDENTIFIER );
+        r( wxSTC_VISUALPROLOG_VARIABLE );
+        r( wxSTC_VISUALPROLOG_ANONYMOUS );
+        r( wxSTC_VISUALPROLOG_NUMBER );
+        r( wxSTC_VISUALPROLOG_OPERATOR );
+        r( wxSTC_VISUALPROLOG_CHARACTER );
+        r( wxSTC_VISUALPROLOG_CHARACTER_TOO_MANY );
+        r( wxSTC_VISUALPROLOG_CHARACTER_ESCAPE_ERROR );
+        r( wxSTC_VISUALPROLOG_STRING );
+        r( wxSTC_VISUALPROLOG_STRING_ESCAPE );
+        r( wxSTC_VISUALPROLOG_STRING_ESCAPE_ERROR );
+        r( wxSTC_VISUALPROLOG_STRING_EOL_OPEN );
+        r( wxSTC_VISUALPROLOG_STRING_VERBATIM );
+        r( wxSTC_VISUALPROLOG_STRING_VERBATIM_SPECIAL );
+        r( wxSTC_VISUALPROLOG_STRING_VERBATIM_EOL );
+#endif            
         r( wxSTC_VISIBLE_SLOP );
         r( wxSTC_VISIBLE_STRICT );
 #if WXPERL_W_VERSION_GE( 2, 6, 0 )
@@ -1729,6 +2260,12 @@ double stc_constant( const char* name, int arg )
         r( wxSTC_V_WORD3 );
         break;
     case 'W':
+#if WXPERL_W_VERSION_GE( 2, 9, 5 )
+        r( wxSTC_WEIGHT_NORMAL );
+        r( wxSTC_WEIGHT_SEMIBOLD );
+        r( wxSTC_WEIGHT_BOLD );
+        r( wxSTC_WRAPVISUALFLAG_MARGIN );
+#endif
         r( wxSTC_WRAP_NONE );
         r( wxSTC_WRAP_WORD );
 #if WXPERL_W_VERSION_GE( 2, 7, 2 )
@@ -1745,6 +2282,11 @@ double stc_constant( const char* name, int arg )
         r( wxSTC_WS_INVISIBLE );
         r( wxSTC_WS_VISIBLEALWAYS );
         r( wxSTC_WS_VISIBLEAFTERINDENT );
+#if WXPERL_W_VERSION_GE( 2, 9, 4 )
+        r( wxSTC_WRAPINDENT_FIXED );
+        r( wxSTC_WRAPINDENT_SAME );
+        r( wxSTC_WRAPINDENT_INDENT ); 
+#endif
         break;
     case 'Y':
         r( wxSTC_YAML_COMMENT );
